@@ -12,6 +12,30 @@ print_dust_latex <- function(x, ..., asis=TRUE)
   
   if (!is.null(x$caption)) increment_pixie_count()
   
+  label <- 
+    if (is.null(x[["label"]]))
+    {
+      chunk_label <- knitr::opts_current$get("label")
+      if (is.null(chunk_label))
+        paste0("tab:pixie-", getOption("pixie_count"))
+      else
+        paste0("tab:", chunk_label)
+    }
+    else
+    {
+      paste0("tab:", x[["label"]])
+    }
+  
+  label <- 
+    if (x[["bookdown"]])
+    {
+      paste0("(\\#", label, ")")
+    }
+    else
+    {
+      paste0("\\label{", label, "}")
+    }
+  
   #* Determine the number of divisions
   #* It looks more complicated than it is, but the gist of it is
   #* total number of divisions: ceiling(total_rows / longtable_rows)
@@ -43,22 +67,48 @@ print_dust_latex <- function(x, ..., asis=TRUE)
   prebegin <- paste0(prebegin, 
                      "\\setlength{\\tabcolsep}{", x$tabcolsep, "pt}", sep = "\n")
   
-  begin <- paste0("\\begin{", tab_env, "}{", 
-                  paste0(col_halign_default$default_halign, collapse = ""), "}\n",
-                  if (tab_env == "longtable" && !is.null(x$caption))
-                    paste0("\\caption{", x$caption, "}\\\\") 
-                  else "")
-  end <- paste0("\\end{", tab_env, "}")
-  
-  if (tab_env != "longtable" & x$float)
+  if (tab_env == "longtable")
+  {
+    begin <- paste0("\\begin{longtable}[",
+                    substr(x[["justify"]], 1, 1), "]{",
+                    paste0(col_halign_default$default_halign, collapse = ""), "}\n",
+                    if (!is.null(x$caption))
+                      paste("\\caption{", x$caption, "}\\\\")
+                    else "", 
+                    "\n", label, "\\\\ \n")
+    end <- "\\end{longtable}"
+  }
+  else if (x$float)
   {
     begin <- paste0("\\begin{table}\n",
-                    if (!is.null(x$caption)) paste0("\\caption{", x$caption, "}\n") else "",
-                    begin)
-    end <- paste0(end, "\n\\end{table}\n")
+                    if (x[["justify"]] == "center") "\\centering\n" else "",
+                    if (!is.null(x$caption))
+                      paste0("\\caption{", x$caption, "}\n")
+                    else "", 
+                    "\n", label,
+                    "\\begin{tabular}{",
+                    paste0(col_halign_default$default_halign, collapse = ""), "}\n")
+    
+    end <- paste0("\\end{tabular}\n\\end{table}\n")
+  }
+  else
+  {
+    begin <- paste0(if (x[["justify"]] == "center")
+                      "\\begin{center}\n"
+                    else
+                      "",
+                    if (!is.null(x$caption))
+                     paste0("\\captionof{table}{", x$caption, "}")
+                    else "", 
+                    "\n", label,
+                    "\\begin{tabular}{",
+                    paste0(col_halign_default$default_halign, collapse = ""), "}\n")
+    end <- paste0("\\end{tabular}\n",
+                  if (x[["justify"]] == "center")
+                    "\\end{center}\n"
+                  else
+                    "")
   }
-  
-  
   
   
   #* Convert each part into a character string
@@ -96,20 +146,20 @@ part_prep_latex <- function(part, col_width, col_halign_default, head=FALSE)
     
     Widths <- part %>%
       dplyr::select(html_row, html_col, width, merge) %>%
-      dplyr::distinct() %>%
+      dplyr::distinct(html_row, html_col, width, merge) %>%
       dplyr::group_by(html_row, html_col) %>%
       dplyr::mutate(width = ifelse(merge == TRUE, 
                             sum(width[merge]),
                             width)) %>%
       dplyr::ungroup()
     
-    part %>% 
-      dplyr::select(-width) %>%
-      dplyr::left_join(Widths,
-                        by = c("html_row" = "html_row", 
-                               "html_col" = "html_col",
-                               "merge" = "merge")) %>%
-      dplyr::mutate(width = ifelse(is.na(width), "", width))
+#     part %>% 
+#       dplyr::select(-width) %>%
+#       dplyr::left_join(Widths,
+#                         by = c("html_row" = "html_row", 
+#                                "html_col" = "html_col",
+#                                "merge" = "merge")) %>%
+#       dplyr::mutate(width = ifelse(is.na(width), "", width))
 
   
   numeric_classes <- c("double", "numeric")
@@ -118,11 +168,23 @@ part_prep_latex <- function(part, col_width, col_halign_default, head=FALSE)
   part <- perform_function(part) 
   
   #* Perform any rounding
-  logic <- part$round != "" & part$col_class %in% numeric_classes
+  logic <- part$round == "" & part$col_class %in% numeric_classes
+  part$round[logic] <- getOption("digits")
+  
+  logic <- part$col_class %in% numeric_classes
   if (any(logic))
-    part$value[logic] <- 
+    part$value[logic] <-
     as.character(roundSafe(part$value[logic], as.numeric(part$round[logic])))
 
+  #* Set NA (missing) values to na_string
+  logic <- is.na(part$value) & !is.na(part$na_string)
+  part$value[logic] <- 
+    part$na_string[logic]
+  
+  #* Sanitize value strings
+  logic <- !is.na(part[["value"]])
+  part[["value"]][logic] <- Hmisc::latexTranslate(part[["value"]][logic])
+  
   #* Bold and italic
   boldify <- part$bold
   part$value[boldify] <- paste0("\\textbf{", part$value[boldify], "}")
@@ -130,11 +192,6 @@ part_prep_latex <- function(part, col_width, col_halign_default, head=FALSE)
   italicize <- part$italic
   part$value[italicize] <- paste0("\\emph{", part$value[italicize], "}")
   
-  #* Set NA (missing) values to na_string
-  logic <- is.na(part$value) & !is.na(part$na_string)
-  part$value[logic] <- 
-    part$na_string[logic]
-  
   #* Font Color
   logic <- part$font_color != ""
   part$font_color <- vapply(part$font_color, 
@@ -161,9 +218,9 @@ part_prep_latex <- function(part, col_width, col_halign_default, head=FALSE)
   #** Background
   logic <- part$bg != ""
   part$bg[logic] <- 
-    paste0("\\cellcolor", vapply(part$bg[logic],
+    paste0("{\\cellcolor", vapply(part$bg[logic],
                                  convertColor,
-                                 character(1)))
+                                 character(1)), "}")
   
   part$value[logic] <- paste(part$bg[logic], part$value[logic])
   
@@ -195,13 +252,9 @@ part_prep_latex <- function(part, col_width, col_halign_default, head=FALSE)
     tidyr::spread(col, top_border) %>%
     dplyr::select(-row) %>%
     apply(1, paste0, collapse = "")
-  
-  
-  
-  
+
   parbox <- needs_parbox(part)
   
-  
   part$halign_parbox <- part$halign
   part$halign_parbox[parbox] <- 
     c("r" = "\\raggedleft", 
@@ -233,13 +286,30 @@ part_prep_latex <- function(part, col_width, col_halign_default, head=FALSE)
             !(part$html_row != part$row & part$html_col == part$col)
   part$value[logic] <- 
     paste0("\\multicolumn{", part$colspan[logic], "}{", 
-           part$left_border[logic], 
-           substr(part$halign[logic], 1, 1), 
+           part$left_border[logic],
+           #* 'p' isn't a valid alignment in 'multicol', so we replace it with 'r'
+           sub("p", "r", substr(part$halign[logic], 1, 1)), 
            part$right_border[logic], "}{", part$value[logic], "}")
   
   #* Remove value where a merged cell is not the display cell
   ncol <- max(part$col)
   part %<>% dplyr::filter(!(rowspan == 0 | colspan == 0))
+
+  #* In order to get the multirow to render correctly, the cell with 
+  #* the multirow needs to be at the top of the block.  This 
+  #* rearranges the merged cells so that the multirow is at the top.
+  
+  proper_multirow <- 
+    part[part$colspan != 1, ] %>%
+    dplyr::mutate(group = paste0(html_row, html_col)) %>%
+    dplyr::group_by(group) %>%
+    dplyr::arrange(dplyr::desc(colspan)) %>%
+    dplyr::mutate(row = sort(row)) %>%
+    dplyr::ungroup()
+  
+  part %<>%
+    dplyr::filter(colspan == 1) %>%
+    dplyr::bind_rows(proper_multirow)
   
   cbind(top_borders, 
         bottom_borders,
@@ -421,8 +491,12 @@ get_column_halign <- function(Joint){
     dplyr::ungroup() 
 }
 
-default_halign <- function(col_class){
-  if (col_class %in% c("numeric", "int", "double")) "r" else "l"
+default_halign <- function(col_class, print_method = "latex"){
+  tag <- 
+    if (print_method == "latex") c("r", "l") 
+    else c("right", "left")
+  
+  if (col_class %in% c("numeric", "int", "double")) tag[1] else tag[2]
 }
 
 #**************************************************
@@ -475,4 +549,5 @@ utils::globalVariables(c("halign", "left_border", "right_border",
                          "require_multicol", "height", "width",
                          "height_units", "width_units", "table_width",
                          "parbox", "width_by_char", "html_row", 
-                         "html_col", "rowspan", "colspan"))
\ No newline at end of file
+                         "html_col", "rowspan", "colspan", "value", "col_name",
+                         "col_class", "group"))
\ No newline at end of file
