@@ -36,29 +36,35 @@
 #' # Causes an error due to too few unnamed arguments
 #' x %>% sprinkle_colnames("Term", "Estimate")
 #' }
+
+#' @rdname sprinkle_colnames
+#' @export
+
 sprinkle_colnames <- function(x, ...)
 {
-  Check <- ArgumentCheck::newArgCheck()
-  if (class(x) != "dust")
-    ArgumentCheck::addError(
-      msg = "Sprinkles may only be added to objects of class 'dust'",
-      argcheck = Check)
-  
+  UseMethod("sprinkle_colnames")
+}
+
+#' @rdname sprinkle_colnames
+#' @export
+
+sprinkle_colnames.default <- function(x, ...)
+{
+  coll <- checkmate::makeAssertCollection()
+
+  checkmate::assertClass(x = x,
+                         classes = "dust")
+
   new_names <- list(...)
   
-  if (any(names(new_names) %in% "")){
-      ArgumentCheck::addError(
-        msg = "Elements of '...' must either all be named or all be unnamed",
-        argcheck = Check)
-    ArgumentCheck::finishArgCheck(Check)      
+  if (any(names(new_names) %in% ""))
+  {
+    coll$push("Elements of '...' must either all be named or all be unnamed")
   }
   #* Return an error if any element in ... has length greater than 1.
   else if (any(vapply(new_names, length, 1) != 1)){
-    ArgumentCheck::addError(
-      msg = "Arguments to '...' should have length 1",
-      argcheck = Check)
-    
-    ArgumentCheck::finishArgCheck(Check)
+    coll$push("Arguments to '...' should have length 1")
+    checkmate::reportAssertions(coll)
   }
   
   #* Return the vector when no names are used
@@ -81,23 +87,31 @@ sprinkle_colnames <- function(x, ...)
     if (any(!names(new_names) %in% x$head$col_name))
     {
       bad_names <- names(new_names)[!names(new_names) %in% x$head$col_name]
-      ArgumentCheck::addError(
-        msg = paste0("The following variable names are not found in the dust table:\n    ",
-                     paste0(bad_names, collapse=", ")),
-        argcheck = Check)
+      coll$push(sprintf("The following variable names are not found in the dust table:\n    %s",
+                        paste0(bad_names, collapse=", ")))
     }
-    ArgumentCheck::finishArgCheck(Check)
+    checkmate::reportAssertions(coll)
     
     x$head$value[match(names(new_names), x$head$col_name)] <- new_names
   } 
   else{
-    if (length(new_names) != max(x$head$col))
-      ArgumentCheck::addError(
-        msg = paste0("colnames sprinkle must have ", max(x$head$col), " values"),
-        argcheck = Check)
-    ArgumentCheck::finishArgCheck(Check)
-    
+    checkmate::assertCharacter(x = new_names,
+                               len = max(x[["head"]][["col"]]),
+                               add = coll)
     x$head$value <- new_names
   }
   x
-}
\ No newline at end of file
+}
+
+#' @rdname sprinkle_colnames
+#' @export
+
+sprinkle_colnames.dust_list <- function(x, ...)
+{
+  structure(
+    lapply(X = x,
+           FUN = sprinkle_colnames,
+           ...),
+    class = "dust_list"
+  )
+}
